@@ -427,10 +427,7 @@ def __get_python_c(args,infile):
         if sys.version[0] == '3' and 'b' in fin.mode:
             l = l.decode('utf-8')
         for c in l:
-            if c == '%':
-                s += '%'
-                s += '%'
-            elif c == '\'':
+            if c == '\'':
                 s += '\\'
                 s += '\''
             elif c == '\\':
@@ -457,7 +454,7 @@ def pythonc_handler(args,parser):
     return
 
 def version_handler(args,parser):
-    sys.stdout.write('insertcode 0.0.6\n')
+    sys.stdout.write('insertcode 0.0.8\n')
     sys.exit(0)
     return
 
@@ -497,7 +494,7 @@ def main():
         }
     }
     '''
-    options = extargsparse.ExtArgsOptions('{ "version" : "0.0.6"}')
+    options = extargsparse.ExtArgsOptions('{ "version" : "0.0.8"}')
     parser = extargsparse.ExtArgsParse()
     parser.load_command_line_string(commandline)
     args = parser.parse_command_line(None,parser)
